@@ -32,24 +32,24 @@
 #'                         `xtx`, the solution will be incorrect. (length p vector)
 #' @param penalty          Penalty function to be applied, either "MCP" (default), "SCAD", or
 #'                         "lasso")
-#' @param gamma            Tuning parameter of the MCP/SCAD penalty, as in `ncvreg()`; default
+#' @param gamma            Tuning parameter of the MCP/SCAD penalty, as in [ncvreg()]; default
 #'                         is 3 for MCP and 3.7 for SCAD.
 #' @param alpha            Tuning paramter controlling the ridge component of penalty, as in
-#'                         `ncvreg()`; default is 1 (meaning no ridge penalty)
+#'                         [ncvreg()]; default is 1 (meaning no ridge penalty)
 #' @param lambda           Regularization parameter value at which to estimate beta; must be
-#'                         scalar -- for pathwise optimization, see `ncvreg()`
+#'                         scalar -- for pathwise optimization, see [ncvreg()]
 #' @param eps              Convergence threshhold. The algorithm iterates until the RMSD for
 #'                         the change in linear predictors for each coefficient is less than
 #'                         eps. Default is 1e-4.
 #' @param max.iter         Maximum number of allowed iterations; if this number is reached,
 #'                         algorithm will terminate prior to convergence.  Default: 1000.
 #' @param penalty.factor   Multiplicative factor for the penalty applied to each coefficient,
-#'                         as in `ncvreg()`.  In particular, note that if you include an
+#'                         as in [ncvreg()].  In particular, note that if you include an
 #'                         intercept, you probably want to set its entry to zero here.
 #' @param warn             Return warning messages for failures to converge and model
 #'                         saturation? Default is TRUE.
 #' 
-#' @return A list containing:
+#' @returns A list containing:
 #' * `beta`: The estimated regression coefficients
 #' * `iter`: The number of iterations required to solve for `beta
 #' * `loss`: The loss (residual sum of squares) at convergence
@@ -71,6 +71,7 @@
 #' coef(ncvreg(X, y), 0.1)
 #' # The unstandardized version makes little sense here, as it fails to account
 #' # for differences in the scales of the predictors.
+#' @export ncvfit
 
 ncvfit <- function(X, y, init=rep(0, ncol(X)), r, xtx, penalty=c("MCP", "SCAD", "lasso"),
                     gamma=switch(penalty, SCAD=3.7, 3), alpha=1, lambda, eps=1e-5,
@@ -79,7 +80,7 @@ ncvfit <- function(X, y, init=rep(0, ncol(X)), r, xtx, penalty=c("MCP", "SCAD",
   # family <- match.arg(family)
   penalty <- match.arg(penalty)
   if (!inherits(X, "matrix")) {
-    tmp <- try(X <- model.matrix(~0+., data=X), silent=TRUE)
+    tmp <- try(X <- stats::model.matrix(~0+., data=X), silent=TRUE)
     if (inherits(tmp, "try-error")) stop("X must be a matrix or able to be coerced to a matrix", call.=FALSE)
   }
   if (typeof(X)=="integer") storage.mode(X) <- "double"
@@ -138,7 +139,5 @@ ncvfit <- function(X, y, init=rep(0, ncol(X)), r, xtx, penalty=c("MCP", "SCAD",
                         loss = loss,
                         penalty.factor = penalty.factor,
                         n = length(y)))
-  #if (family=="poisson") val$y <- y
-  #if (family=="binomial") val$Eta <- Eta
   val
 }
